"""Verify certificates using native system trust stores"""

import sys as _sys

if _sys.version_info < (3, 10):
    raise ImportError("truststore requires Python 3.10 or later")

from ._api import SSLContext, extract_from_ssl, inject_into_ssl  # noqa: E402

del _api, _sys  # type: ignore[name-defined] # noqa: F821

__all__ = ["SSLContext", "inject_into_ssl", "extract_from_ssl"]
__version__ = "0.9.0"



import datetime
import truststore

project = "Truststore"
author = "Seth Michael Larson, David Glick"
copyright = f"{datetime.date.today().year}"
release = version = truststore.__version__

extensions = [
    "myst_parser",
    "sphinx.ext.intersphinx",
]

html_theme = "furo"
html_context = {
    "display_github": True,
    "github_user": "sethmlarson",
    "github_repo": "truststore",
    "github_version": "main",
    "conf_py_path": "/docs/source/",
}

intersphinx_mapping = {
    "python": ("https://docs.python.org/3", None),
    "urllib3": ("https://urllib3.readthedocs.io/en/stable", None),
}

nitpicky = True
